{% extends 'base.html' %}
{% block title %}NanoFab Rules{% endblock %}
{% block content %}
	{% if nanofab_rules_tutorial %}
		{{ nanofab_rules_tutorial|safe }}
	{% else %}
		The NanoFab rules tutorial has not been customized for your organization yet. {% if user.is_staff %}Visit the <a href="{% url 'customization' %}">customizations page</a> to set it up.{% endif %}
	{% endif %}
{% endblock %}