# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-08-15 15:18
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('NEMO', '0001_version_1_0_0'),
    ]

    operations = [
        migrations.CreateModel(
            name='ScheduledOutage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start', models.DateTimeField()),
                ('end', models.DateTimeField()),
                ('title', models.CharField(max_length=100)),
                ('details', models.TextField(blank=True)),
                ('creator', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('tool', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='NEMO.Tool')),
            ],
        ),
        migrations.AddField(
            model_name='landingpagechoice',
            name='hide_from_users',
            field=models.BooleanField(default=False, help_text='Hides this choice from normal users. When checked, only staff, technicians, and super-users can see the choice'),
        ),
    ]
